@@ -6,7 +6,7 @@ from django.contrib.auth.models import User
 from django.test import TestCase, Client
 from djangorestframework import status
 from djangorestframework.authentication import UserLoggedInAuthentication
-from djangorestframework.compat import RequestFactory
+from djangorestframework.compat import RequestFactory, unittest
 from djangorestframework.mixins import RequestMixin
 from djangorestframework.parsers import FormParser, MultiPartParser, \
     PlainTextParser, JSONParser
@@ -17,7 +17,7 @@ class MockView(View):
     authentication = (UserLoggedInAuthentication,)
     def post(self, request):
         if request.POST.get('example') is not None:
-            return Response(status.OK)
+            return Response(status.HTTP_200_OK)
 
         return Response(status.INTERNAL_SERVER_ERROR)
 
@@ -114,21 +114,22 @@ class TestContentParsing(TestCase):
         self.assertEqual(view.DATA.items(), form_data.items())
         self.assertEqual(view.request.POST.items(), form_data.items())
 
-    # def test_accessing_post_after_data_for_json(self):
-    #     """Ensures request.POST can be accessed after request.DATA in json request"""
-    #     from django.utils import simplejson as json
+    @unittest.skip('This test was disabled some time ago for some reason')
+    def test_accessing_post_after_data_for_json(self):
+        """Ensures request.POST can be accessed after request.DATA in json request"""
+        from django.utils import simplejson as json
 
-    #     data = {'qwerty': 'uiop'}
-    #     content = json.dumps(data)
-    #     content_type = 'application/json'
+        data = {'qwerty': 'uiop'}
+        content = json.dumps(data)
+        content_type = 'application/json'
 
-    #     view = RequestMixin()
-    #     view.parsers = (JSONParser,)
+        view = RequestMixin()
+        view.parsers = (JSONParser,)
 
-    #     view.request = self.req.post('/', content, content_type=content_type)
+        view.request = self.req.post('/', content, content_type=content_type)
 
-    #     self.assertEqual(view.DATA.items(), data.items())
-    #     self.assertEqual(view.request.POST.items(), [])
+        self.assertEqual(view.DATA.items(), data.items())
+        self.assertEqual(view.request.POST.items(), [])
 
     def test_accessing_post_after_data_for_overloaded_json(self):
         """Ensures request.POST can be accessed after request.DATA in overloaded json request"""
@@ -214,10 +215,10 @@ class TestContentParsingWithAuthentication(TestCase):
         content = {'example': 'example'}
 
         response = self.client.post('/', content)
-        self.assertEqual(status.OK, response.status_code, "POST data is malformed")
+        self.assertEqual(status.HTTP_200_OK, response.status_code, "POST data is malformed")
 
         response = self.csrf_client.post('/', content)
-        self.assertEqual(status.OK, response.status_code, "POST data is malformed")
+        self.assertEqual(status.HTTP_200_OK, response.status_code, "POST data is malformed")
 
     # def test_user_logged_in_authentication_has_post_when_logged_in(self):
     #     """Ensures request.POST exists after UserLoggedInAuthentication when user does log in"""
